@@ -10,8 +10,8 @@
 *
 * $Project: /Convert-Binary-C $
 * $Author: mhx $
-* $Date: 2005/02/21 10:18:38 +0100 $
-* $Revision: 2 $
+* $Date: 2005/05/19 19:53:43 +0200 $
+* $Revision: 3 $
 * $Source: /cbc/option.h $
 *
 ********************************************************************************
@@ -54,4 +54,7 @@ SV *get_configuration(pTHX_ CBC *THIS);
 #define get_native_property CBC_get_native_property
 SV *get_native_property(pTHX_ const char *property);
 
+#define post_configure_update CBC_post_configure_update
+void post_configure_update(pTHX_ CBC *THIS);
+
 #endif
